@@ -69,29 +69,32 @@ public class Grammatica extends Object {
         "  --parse <file>\n" +
         "      Debugs the grammar by using it to parse the specified\n" +
         "      file. No code has to be generated for this.\n" +
+        "  --csoutput <dir>\n" +
+        "      Creates a C# parser for the grammar (in source code).\n" +
+        "      The specified directory with be used when generating\n" +
+        "      source code files.\n" +
         "  --javaoutput <dir>\n" +
         "      Creates a Java parser for the grammar (in source code).\n" +
         "      The specified directory with be used as base directory\n" +
         "      when generating source code files.\n" +
-        "  --csoutput <dir>\n" +
-        "      Creates a C# parser for the grammar (in source code).\n" +
-        "      The specified directory with be used as base directory\n" +
-        "      when generating source code files.\n" +
         "\n" +
-        "Options:\n" +
+        "C# Output Options:\n" +
+        "  --csnamespace <package>\n" +
+        "      Sets the C# namespace to use in generated source code files.\n" +
+        "  --csclassname <name>\n" +
+        "      Sets the C# class name prefix to use in generated source\n" +
+        "      code files.\n" +
+        "  --cspublic\n" +
+        "      Sets public access for all C# types generated.\n" +
+        "\n" +
+        "Java Output Options:\n" +
         "  --javapackage <package>\n" +
         "      Sets the Java package to use in generated source code files.\n" +
         "  --javaclassname <name>\n" +
         "      Sets the Java class name prefix to use in generated source\n" +
         "      code files.\n" +
         "  --javapublic\n" +
-        "      Sets public access for all Java classes and interfaces\n" +
-        "      generated.\n" +
-        "  --csnamespace <package>\n" +
-        "      Sets the C# namespace to use in generated source code files.\n" +
-        "  --csclassname <name>\n" +
-        "      Sets the C# class name prefix to use in generated source\n" +
-        "      code files.";
+        "      Sets public access for all Java types.";
 
     /**
      * The application entry point.
@@ -264,6 +267,8 @@ public class Grammatica extends Object {
                 gen.setNamespace(args[++i]);
             } else if (args[i].equals("--csclassname")) {
                 gen.setBaseName(args[++i]);
+            } else if (args[i].equals("--cspublic")) {
+                gen.setPublicAccess(true);
             } else {
                 printHelp("unrecognized option: " + args[i]);
                 System.exit(1);
