@@ -287,9 +287,12 @@ class SecondPassAnalyzer extends GrammarAnalyzer {
             break;
         }
 
-        // Handle optional '*' or '+'
+        // Handle optional '?', '*' or '+'
         child = node.getChildAt(node.getChildCount() - 1);
-        if (child.getId() == GrammarConstants.ASTERISK) {
+        if (child.getId() == GrammarConstants.QUESTION_MARK) {
+            min = 0;
+            max = 1;
+        } else if (child.getId() == GrammarConstants.ASTERISK) {
             min = 0;
             max = -1;
         } else if (child.getId() == GrammarConstants.PLUS_SIGN) {
