@@ -59,7 +59,7 @@ class JavaParserFile {
     /**
      * The class comment.
      */
-    private static final String CLASS_COMMENT =
+    private static final String TYPE_COMMENT =
         "A token stream parser.";
 
     /**
@@ -183,7 +183,7 @@ class JavaParserFile {
 
         // Add class
         file.addClass(cls);
-        str = CLASS_COMMENT;
+        str = TYPE_COMMENT;
         if (gen.getClassComment() != null) {
             str += "\n\n" + gen.getClassComment();
         }
