@@ -278,35 +278,35 @@ public abstract class Node {
      * Prints this node and all subnodes to the specified output 
      * stream.
      * 
-     * @param out            the output stream to use
+     * @param output         the output stream to use
      */
-    public void printTo(PrintStream out) {
-        printTo(new PrintWriter(out));
+    public void printTo(PrintStream output) {
+        printTo(new PrintWriter(output));
     }
     
     /**
      * Prints this node and all subnodes to the specified output 
      * stream.
      * 
-     * @param out            the output stream to use
+     * @param output         the output stream to use
      */
-    public void printTo(PrintWriter out) {
-        printTo(out, "");
-        out.flush();
+    public void printTo(PrintWriter output) {
+        printTo(output, "");
+        output.flush();
     }
     
     /**
      * Prints this node and all subnodes to the specified output 
      * stream.
      * 
-     * @param out            the output stream to use
+     * @param output         the output stream to use
      * @param indent         the indentation string
      */
-    private void printTo(PrintWriter out, String indent) {
-        out.println(indent + toString());
+    private void printTo(PrintWriter output, String indent) {
+        output.println(indent + toString());
         indent = indent + "  ";
         for (int i = 0; i < getChildCount(); i++) {
-            getChildAt(i).printTo(out, indent);
+            getChildAt(i).printTo(output, indent);
         }
     }
 }
