@@ -33,7 +33,7 @@
 
 package net.percederberg.grammatica.parser;
 
-import java.util.Vector;
+import java.util.ArrayList;
 
 /**
  * A production pattern. This class represents a set of production
@@ -67,7 +67,7 @@ public class ProductionPattern {
     /**
      * The list of production pattern alternatives.
      */
-    private Vector alternatives;
+    private ArrayList alternatives;
 
     /**
      * The default production pattern alternative. This alternative
@@ -91,7 +91,7 @@ public class ProductionPattern {
         this.id = id;
         this.name = name;
         this.syntetic = false;
-        this.alternatives = new Vector();
+        this.alternatives = new ArrayList();
         this.defaultAlt = -1;
         this.lookAhead = null;
     }
