@@ -369,7 +369,7 @@ public class RecursiveDescentParser extends Parser {
         }
         
         // Create exception
-        token = peekToken(0);
+        token = nextToken();
         return new ParseException(ParseException.UNEXPECTED_TOKEN_ERROR,
                                   token.toShortString(),
                                   list,
@@ -669,31 +669,31 @@ public class RecursiveDescentParser extends Parser {
 
         ProductionPattern  pattern;
         LookAheadSet       result;
-        LookAheadSet       base;
+        LookAheadSet       set;
         int                max;
 
         // Find look-ahead for this element
         if (elem.isToken()) {
-            base = new LookAheadSet(length);
-            base.add(elem.getId());
+            set = new LookAheadSet(length);
+            set.add(elem.getId());
         } else {
             pattern = getPattern(elem.getId());
-            base = findLookAhead(pattern, length, stack);
+            set = findLookAhead(pattern, length, stack);
             if (stack.contains(pattern.getName())) {
-                base = base.createRepetitive();
+                set = set.createRepetitive();
             }
         }
 
         // Handle element repetitions
         result = new LookAheadSet(length);
-        result.addAll(base);
+        result.addAll(set);
         if (elem.getMaxCount() == Integer.MAX_VALUE) {
-            base = base.createRepetitive();
+            set = set.createRepetitive();
         }
         max = Math.min(length, elem.getMaxCount());
         for (int i = 1; i < max; i++) {
-            base = base.createCombination(base);
-            result.addAll(base);
+            set = set.createCombination(set);
+            result.addAll(set);
         }
         
         return result;
