@@ -55,7 +55,7 @@ import net.percederberg.grammatica.parser.re.RegExpException;
 public class Tokenizer {
     
     /**
-     * The vector with all token pattern matchers.
+     * The list of all token pattern matchers.
      */
     private ArrayList matchers = new ArrayList();
 
@@ -63,7 +63,7 @@ public class Tokenizer {
      * The input stream to read from. When this is set to null, no
      * further input is available.
      */
-    private Reader in = null;
+    private Reader input = null;
 
     /**
      * The buffer with previously read characters. Normally characters
@@ -98,10 +98,10 @@ public class Tokenizer {
     /**
      * Creates a new tokenizer for the specified input stream.
      * 
-     * @param in             the input stream to read
+     * @param input          the input stream to read
      */
-    public Tokenizer(Reader in) {
-        this.in = in;
+    public Tokenizer(Reader input) {
+        this.input = input;
     }
     
     /**
@@ -231,12 +231,12 @@ public class Tokenizer {
 
         // Find longest matching string 
         do {
-            endOfBuffer = false;
-            m = findMatch();
             if (endOfBuffer) {
                 readInput();
+                endOfBuffer = false;
             }
-        } while (endOfBuffer && in != null);
+            m = findMatch();
+        } while (endOfBuffer && input != null);
 
         // Return token results
         if (m != null) {
@@ -271,7 +271,7 @@ public class Tokenizer {
         int   length;
 
         // Check for end of file
-        if (in == null) {
+        if (input == null) {
             return;
         }
 
@@ -283,9 +283,9 @@ public class Tokenizer {
 
         // Read characters
         try {
-            length = in.read(chars);
+            length = input.read(chars);
         } catch (IOException e) {
-            in = null;
+            input = null;
             throw new ParseException(ParseException.IO_ERROR,
                                      e.getMessage(),
                                      -1,
@@ -295,13 +295,14 @@ public class Tokenizer {
         // Append characters to buffer
         if (length > 0) {
             buffer.append(chars, 0, length);
-        } else {
+        }
+        if (length < chars.length) {
             try {
-                in.close();
+                input.close();
             } catch (IOException e) {
                 // Do nothing
             }
-            in = null;
+            input = null;
         }
     }
     
